from _typeshed import Incomplete
from cf_extension_core.constants import DynamoDBValues as DynamoDBValues
from mypy_boto3_dynamodb.service_resource import DynamoDBServiceResource
from typing import TYPE_CHECKING

logger: Incomplete

class DynamoTableCreator:
    _client: Incomplete
    def __init__(self, db_resource: DynamoDBServiceResource) -> None: ...
    def delete_table(self) -> None: ...
    def table_exists(self) -> bool: ...
    def create_standard_table(self) -> None: ...
    def _create_table(self, name: str, partition_key: str) -> None: ...
    def _wait_for_table_to_be_active(self) -> None: ...
    def _wait_for_table_to_be_deleted(self) -> None: ...
